@@ -51,6 +51,8 @@
 #include xstr(VIDEXT_HEADER)
 #endif
 
+#define PIF_ROM_SIZE 2048
+
 /* Version number for UI-Console config section parameters */
 #define CONFIG_PARAM_VERSION     1.00
 
@@ -159,8 +161,9 @@ static void FrameCallback(unsigned int FrameIndex)
     }
 }
 
+static char *formatstr(const char *fmt, ...) ATTR_FMT(1, 2);
 
-static char *formatstr(const char *fmt, ...)
+char *formatstr(const char *fmt, ...)
 {
 	int size = 128, ret;
 	char *str = (char *)malloc(size), *newstr;
@@ -387,6 +390,7 @@ static void printUsage(const char *progname)
            "    --core-compare-send    : use the Core Comparison debugging feature, in data sending mode\n"
            "    --core-compare-recv    : use the Core Comparison debugging feature, in data receiving mode\n"
            "    --nosaveoptions        : do not save the given command-line options in configuration file\n"
+           "    --pif (filepath)       : use a binary PIF ROM (filepath) instead of HLE PIF\n"
            "    --verbose              : print lots of information\n"
            "    --help                 : see this help message\n\n"
            "(plugin-spec):\n"
@@ -732,6 +736,30 @@ static m64p_error ParseCommandLineMain(int argc, const char **argv)
             ConfigSetParameter(l_Config64DD, "Disk", M64TYPE_STRING, argv[i+1]);
             i++;
         }
+        else if (strcmp(argv[i], "--pif") == 0)
+        {
+            m64p_error pif_status = M64ERR_INVALID_STATE;
+            /* load PIF image */
+            FILE *pifPtr = fopen(argv[i+1], "rb");
+            if (pifPtr != NULL)
+            {
+                unsigned char *PIF_buffer = (unsigned char *) malloc(PIF_ROM_SIZE);
+                if (PIF_buffer != NULL)
+                {
+                    if (fread(PIF_buffer, 1, PIF_ROM_SIZE, pifPtr) == PIF_ROM_SIZE)
+                    {
+                        pif_status = (*CoreDoCommand)(M64CMD_PIF_OPEN, PIF_ROM_SIZE, PIF_buffer);
+                    }
+                    free(PIF_buffer);
+                }
+                fclose(pifPtr);
+            }
+            if (pif_status != M64ERR_SUCCESS)
+            {
+                DebugMessage(M64MSG_ERROR, "core failed to open PIF ROM file '%s'.", argv[i+1]);
+            }
+            i++;
+        }
         else if (ArgsLeft == 0)
         {
             /* this is the last arg, it should be a ROM filename */
@@ -858,6 +886,7 @@ static m64p_media_loader l_media_loader =
     NULL,
     media_loader_get_gb_cart_rom,
     media_loader_get_gb_cart_ram,
+    NULL,
     media_loader_get_dd_rom,
     media_loader_get_dd_disk
 };
